@@ -33,7 +33,6 @@ You can see the the list of all available commands by running:
     Commands:
       info      Get info about the current tango installation.
       run       Run a tango experiment.
-      server    Run a local webserver that watches a workspace.
       settings  Commands for initializing and updating global settings.
 
 To see all of the available arguments and options for a particular command, run
@@ -61,12 +60,6 @@ for a quick introduction to the format.
 The ``info`` command just prints out some useful information about the current tango installation,
 such as which integrations are available.
 
-``tango server``
-----------------
-
-The ``server`` command spins up a web server that watches a workspace. You can use this to track the
-progress of your runs while they are happening.
-
 ``tango settings``
 ------------------
 
@@ -80,7 +73,7 @@ import os
 import sys
 import warnings
 from pathlib import Path
-from typing import TYPE_CHECKING, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Union
 
 import click
 from click_help_colors import HelpColorsCommand, HelpColorsGroup
@@ -257,12 +250,6 @@ def cleanup(*args, **kwargs):
     help="Python packages or modules to import for tango components.",
     multiple=True,
 )
-@click.option(
-    "--server/--no-server",
-    type=bool,
-    help="Start a server that visualizes the current run.",
-    default=False,
-)
 @click.option(
     "-j",
     "--parallelism",
@@ -285,6 +272,14 @@ def cleanup(*args, **kwargs):
     type=str,
     help="""Specify the name for this run.""",
 )
+@click.option(
+    "-D",
+    "--ext-var",
+    type=str,
+    help="""JSONNET external variables to use when loading the experiment config.
+    For example, --ext-var 'pretrained_model=gpt2'.""",
+    multiple=True,
+)
 @click.pass_obj
 def run(
     settings: TangoGlobalSettings,
@@ -293,10 +288,10 @@ def run(
     workspace_dir: Optional[Union[str, os.PathLike]] = None,
     overrides: Optional[str] = None,
     include_package: Optional[Sequence[str]] = None,
-    server: bool = True,
     parallelism: Optional[int] = None,
     step_name: Optional[str] = None,
     name: Optional[str] = None,
+    ext_var: Optional[Sequence[str]] = None,
 ):
     """
     Run a tango experiment.
@@ -324,11 +319,11 @@ def run(
         workspace_url=workspace,
         overrides=overrides,
         include_package=include_package,
-        start_server=server,
         parallelism=parallelism,
         step_name=step_name,
         name=name,
         called_by_executor=_CALLED_BY_EXECUTOR,
+        ext_var=ext_var,
     )
 
 
@@ -391,58 +386,6 @@ def beaker_executor_run(
     executor.execute_step(step)
 
 
-@main.command(**_CLICK_COMMAND_DEFAULTS)
-@click.option(
-    "-w",
-    "--workspace",
-    type=click.Path(file_okay=False),
-    help="""A workspace URL. If not specified, the workspace from any global tango
-    settings file will be used, if found, otherwise an ephemeral MemoryWorkspace.""",
-    default=None,
-)
-@click.option(
-    "-d",
-    "--workspace-dir",
-    type=click.Path(file_okay=False),
-    default=None,
-    hidden=True,
-)
-@click.pass_obj
-def server(
-    settings: TangoGlobalSettings,
-    workspace: Optional[str],
-    workspace_dir: Optional[Union[str, os.PathLike]] = None,
-):
-    """
-    Run a local webserver that watches a workspace.
-    """
-    from tango.server.workspace_server import WorkspaceServer
-    from tango.workspaces import LocalWorkspace
-
-    workspace_to_watch: Workspace
-    if workspace_dir is not None:
-        if workspace is not None:
-            raise click.ClickException(
-                "-w/--workspace is mutually exclusive with -d/--workspace-dir"
-            )
-        workspace_to_watch = LocalWorkspace(workspace_dir)
-    elif workspace is not None:
-        workspace_to_watch = Workspace.from_url(workspace)
-    elif settings.workspace is not None:
-        workspace_to_watch = Workspace.from_params(settings.workspace)
-    else:
-        raise click.ClickException(
-            "-w/--workspace or -d/--workspace-dir required unless a default workspace is specified "
-            "in tango settings file."
-        )
-
-    server = WorkspaceServer.on_free_port(workspace_to_watch)
-    cli_logger.info(
-        "Server started at [bold underline]%s[/bold underline]", server.address_for_display()
-    )
-    server.serve_forever()
-
-
 @main.command(**_CLICK_COMMAND_DEFAULTS)
 @click.pass_obj
 def info(settings: TangoGlobalSettings):
@@ -701,20 +644,26 @@ def _run(
     workspace_url: Optional[str] = None,
     overrides: Optional[str] = None,
     include_package: Optional[Sequence[str]] = None,
-    start_server: bool = True,
     step_name: Optional[str] = None,
     parallelism: Optional[int] = None,
     multicore: Optional[bool] = None,
     name: Optional[str] = None,
     called_by_executor: bool = False,
+    ext_var: Optional[Sequence[str]] = None,
 ) -> str:
     from tango.executor import Executor
     from tango.executors import MulticoreExecutor
-    from tango.server.workspace_server import WorkspaceServer
     from tango.workspaces import MemoryWorkspace, default_workspace
 
     # Read params.
-    params = Params.from_file(experiment, params_overrides=overrides or "")
+    ext_vars: Dict[str, str] = {}
+    for var in ext_var or []:
+        try:
+            key, value = var.split("=")
+        except ValueError:
+            raise CliRunError(f"Invalid --ext-var '{var}'")
+        ext_vars[key] = value
+    params = Params.from_file(experiment, params_overrides=overrides or "", ext_vars=ext_vars)
 
     # Import included packages to find registered components.
     # NOTE: The Executor imports these as well because it's meant to be used
@@ -746,7 +695,7 @@ def _run(
             settings.executor,
             workspace=workspace,
             include_package=include_package,
-            parallelism=parallelism,
+            **(dict(parallelism=parallelism) if parallelism is not None else {}),  # type: ignore
         )
     else:
         # Determine if we can use the multicore executor.
@@ -797,17 +746,9 @@ def _run(
         run = workspace.register_run((step for step in step_graph.values()), name)
 
     def log_and_execute_run():
-        if step_name is None:
+        if not called_by_executor:
             cli_logger.info("[green]Starting new run [bold]%s[/][/]", run.name)
 
-        # Initialize server.
-        if start_server:
-            server = WorkspaceServer.on_free_port(workspace)
-            server.serve_in_background()
-            cli_logger.info(
-                "Server started at [bold]%s[/bold]", server.address_for_display(run.name)
-            )
-
         executor_output: Optional[ExecutorOutput] = None
         if step_name is not None:
             assert sub_graph is not None
