@@ -82,7 +82,7 @@ class FlaxTrainStep(Step):
         seed: int = 42,
         keep_checkpoints: int = 5,
         lr_scheduler: Optional[Lazy[LRScheduler]] = None,
-        train_split: Optional[str] = None,
+        train_split: str = "train",
         validation_dataloader: Optional[Lazy[FlaxDataLoader]] = None,
         validation_split: Optional[str] = None,
         train_steps: Optional[int] = None,
@@ -202,7 +202,7 @@ class FlaxTrainStep(Step):
         seed: int = 42,
         keep_checkpoints: int = 5,
         lr_scheduler: Optional[Lazy[LRScheduler]],
-        train_split: Optional[str] = "train",
+        train_split: str = "train",
         validation_split: Optional[str] = None,
         validation_dataloader: Optional[Lazy[FlaxDataLoader]] = None,
         train_steps: Optional[int] = None,
@@ -291,6 +291,12 @@ class FlaxTrainStep(Step):
         validation_dataloader: Optional[Lazy[FlaxDataLoader]] = None,
         callbacks: Optional[List[Lazy[TrainCallback]]] = None,
     ) -> PyTree:
+        if lr_scheduler is not None:
+            raise NotImplementedError(
+                "Learning rate scheduling is not supported by the flax trainer. "
+                "Please voice your support for this feature at "
+                "https://github.com/allenai/tango/issues/477."
+            )
 
         logger = logging.getLogger(FlaxTrainStep.__name__)
 
@@ -306,10 +312,8 @@ class FlaxTrainStep(Step):
 
         validation_dataloader = validation_dataloader_
 
-        train_dataset = dataset
-        if config.train_split is not None:
-            train_dataset = dataset[config.train_split]
-            train_dataset.set_format("numpy")  # type:ignore
+        train_dataset = dataset[config.train_split]
+        train_dataset.set_format("numpy")  # type:ignore
         train_dataloader: FlaxDataLoader = train_dataloader.construct(dataset=train_dataset)
 
         devices = self._get_devices()
@@ -394,7 +398,7 @@ class FlaxTrainStep(Step):
         if start_step > 0:
             with Tqdm.tqdm(
                 train_dataloader,
-                desc=f"Catching dataloader upto step {start_step}",
+                desc=f"Catching dataloader up to step {start_step}",
                 total=start_step - 1,
             ) as batch_iter:
                 for step, batch in enumerate(batch_iter):
